KeyPair class

Constructors

KeyPair.fresh()
Creates a fresh private and public key for ECDH with 512 bits from a secure random algorithm.

Properties

hashCode → int
The hash code for this object.
no setterinherited
privateKeyHex ↔ String
This should be kept private to each user who generated a KeyPair
getter/setter pair
publicKeyHex ↔ String
This can be published
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

computeSharedSecret(String privateKeyHex, String publicKeyHex) → BigInt
Computes the shared secret of Alice and Bob based on two Hexadecimal Strings
parsePrivateKey(String privateKeyHex) → BigInt
Parses a Hex-String to a BigInt
parsePublicKey(String publicKey) → EllipticCurvePoint
parses a serialized elliptic curve poimnt
randomBigInt(int bitLength) → BigInt
Creates a random Big Integer with roughly bitLength amount of bits using a secure random generator. If you need EXACTLY bigLength amount of bits, you might need to pad the resulting BigInt