M511 class

Constructors

M511()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

A BigInt
final
secureBasePoint EllipticCurvePoint
A secure based point from a paper
final
three BigInt
final
unnecessarilyLargePrimeWithLowCofactor BigInt
final

Static Methods

add(EllipticCurvePoint a, EllipticCurvePoint b) EllipticCurvePoint
Adds the elliptic curve points according to their group law and returns the result.
multiply(EllipticCurvePoint ellipticCurvePoint, BigInt n) EllipticCurvePoint
Multiplies an elliptic curve point with another number usind the efficient double and add scheme. NOTE: This is not secure against side-channel-attacks. If you need security against side-channel-attacks, change the if statement so that both clauses consume the same amount of CPU cycles and energy in any case.