Multiplies an elliptic curve point with another number usind the efficient
double and add scheme. NOTE: This is not secure against side-channel-attacks.
If you need security against side-channel-attacks, change the if statement
so that both clauses consume the same amount of CPU cycles and energy in any case.